@@ -1,12 +1,12 @@
 package Test::Count::FileMutator;
-$Test::Count::FileMutator::VERSION = '0.1100';
+$Test::Count::FileMutator::VERSION = '0.1101';
 use warnings;
 use strict;
 
-use base 'Test::Count::Base';
+use parent 'Test::Count::Base';
 
-use Test::Count;
-use Test::Count::Lib;
+use Test::Count      ();
+use Test::Count::Lib ();
 
 
 sub _counter
@@ -141,7 +141,7 @@ __END__
 
 =head1 VERSION
 
-version 0.1100
+version 0.1101
 
 =head1 SYNOPSIS
 
