@@ -1,12 +1,12 @@
 package Test::Count::Filter::ByFileType::App;
-$Test::Count::Filter::ByFileType::App::VERSION = '0.1100';
+$Test::Count::Filter::ByFileType::App::VERSION = '0.1101';
 use strict;
 use warnings;
 
-use Test::Count::Filter;
-use Getopt::Long;
+use Test::Count::Filter ();
+use Getopt::Long qw/ GetOptions /;
 
-use base 'Exporter';
+use parent 'Exporter';
 
 our @EXPORT = (qw(run));
 
@@ -56,7 +56,7 @@ __END__
 
 =head1 VERSION
 
-version 0.1100
+version 0.1101
 
 =head1 SYNOPSIS
 
