@@ -1,13 +1,13 @@
 package Test::Count::Parser;
-$Test::Count::Parser::VERSION = '0.1100';
+$Test::Count::Parser::VERSION = '0.1101';
 use warnings;
 use strict;
 
-use base 'Test::Count::Base';
+use parent 'Test::Count::Base';
 
 use File::Basename (qw(dirname));
 
-use Parse::RecDescent;
+use Parse::RecDescent ();
 
 
 sub _get_grammar
@@ -198,11 +198,11 @@ __END__
 
 =head1 VERSION
 
-version 0.1100
+version 0.1101
 
 =head1 SYNOPSIS
 
-    use Test::Count::Parser;
+    use Test::Count::Parser ();
 
     my $parser = Test::Count::Parser->new();
 
